Contributing
************

Important notes
===============

Code style
----------
Regarding code style like indentation(4 spaces) and whitespace, **follow the conventions you see used in the source already.**

Modifying the code
------------------
* Ensure that you have python 2.7 installed and running
* Download all the requirements by running the command ::
    pip install -r requirements.txt

Submitting pull requests
------------------------
1. Fork and clone the repo.
2. Create a new branch, please don't work in your *master* branch directly.
#. Implement a feature.
#. Run to check if things work. Repeat step 3-4. Until things get working.
#. Update the documentation to reflect any changes.
#. Push to your fork and submit a pull request.
